==> linkv_rtc_im_mini-0.0.1.tar.gz: lib/linkv_api_defines.dart <==
import 'dart:typed_data';
import 'dart:convert' show utf8;

import 'package:linkv_rtc_im_mini/bean/lv_im_audio_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_image_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_video_msg.dart';

enum LVCameraPosition {
  back, // 后置摄像头
  front, // 前置摄像头
}

enum LVAVConfig {
  PROFILE_180P,
  PROFILE_270P,
  PROFILE_360P,
  PROFILE_540P,
  PROFILE_720P,
}

enum LVBeauty {
  Beauty, // 美颜级别
  Bright, // 明亮度
  Tone // 饱和度
}

class LVIMEnumDefine {

  ///操作的数据库类型
  ///房间数据库类型
  static const int LVIMDB_TYPE_ROOM = 1;
  ///群组数据库类型
  static const int LVIMDB_TYPE_GROUP = 2;
  ///私信数据库类型
  static const int LVIMDB_TYPE_PRIVATE = 3;
  ///系统数据库类型
  static const int LVIMDB_TYPE_SYSTEM = 4;

  /// 直播间数据管理
  /// 直播间数据添加
  static const int LVIM_ROOM_DATA_ADD          = 0;
  static const int LVIM_ROOM_DATA_UPDATE      = 1; ///直播间数据修改
  static const int LVIM_ROOM_DATA_REMOVE      = 2; ///直播间数据删除
  static const int LVIM_ROOM_DATA_QUERY       = 3; ///查询直播间某一个数据
  static const int LVIM_ROOM_DATA_QUERY_ALL   = 4; ///查询直播间所有数据

  static const int LVIM_ROOM_USER_DATA_ADD    = 0; ///直播间用户数据添加
  static const int LVIM_ROOM_USER_DATA_UPDATE = 1; ///直播间用户数据修改
  static const int LVIM_ROOM_USER_DATA_REMOVE = 2; ///直播间用户数据删除
  static const int LVIM_ROOM_USER_DATA_QUERY  = 4; ///查询直播间用户某一个数据
  static const int LVIM_ROOM_USER_DATA_QUERY_ALL  = 5; ///查询直播间用户所有数据

  ///登录类型
  ///手动登录
  static const int LVIM_LOGIN_TYPE_MANUAL = 0;
  ///自动登录
  static const int LVIM_LOGIN_TYPE_AUTO = 1;

  ///登录被踢类型
  ///有新的设备登录账号
  static const int LVIM_LOGIN_KICKED_CODE_KICKED = -5;
  ///用户拉黑
  static const int LVIM_LOGIN_KICKED_CODE_BAN = -9;

  /// 消息类型
  ///文本类协议
  static const int IM_SUBTYPE_TEXT = 0;

  ///图片类协议
  static const int IM_SUBTYPE_IMAGE = 1;

  ///音频类协议
  static const int IM_SUBTYPE_AUDIO = 2;

  ///视频类协议
  static const int IM_SUBTYPE_VIDEO = 3;

  ///军团文本类协议
  static const int IM_SUBTYPE_LEGION_TEXT = 5;

  ///军团图片类协议
  static const int IM_SUBTYPE_LEGION_IMAGE = 6;

  ///军团音频类协议
  static const int IM_SUBTYPE_LEGION_AUDIO = 7;

  ///军团视频类协议
  static const int IM_SUBTYPE_LEGION_VIDEO = 8;

  ///直播间消息
  static const int IM_SUBTYPE_ROOMDIY = 80;

  ///无效最小值
  static const int IM_MEDIA_FILE_TYPE_MIN = 0;
  ///图片文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_IMAGE = 1;
  ///语音文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_AUDIO = 2;
  ///视频文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_VIDEO = 3;
  ///文件文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_FILE = 4;
  ///图片文件(群组)
  static const int IM_MEDIA_FILE_GROUP_IMAGE = 5;
  ///语音文件(群组)
  static const int IM_MEDIA_FILE_GROUP_AUDIO = 6;
  ///视频文件(群组)
  static const int IM_MEDIA_FILE_GROUP_VIDEO = 7;
  ///文件文件(群组)
  static const int IM_MEDIA_FILE_GROUP_FILE = 8;
  ///无效最大值
  static const int IM_MEDIA_FILE_TYPE_MAX = 9;

  ///用户黑名单 参数错误，请确认 toUserId 是否为空，超出长度
  static const int LVIM_PRIVATE_BLACK_PARAMS_FAILED = 5050;
  ///用户黑名单，黑名单创建失败
  static const int LVIM_PRIVATE_BLACK_CREATE_FAILED = 5051;
  ///用户黑名单，黑名单删除失败
  static const int LVIM_PRIVATE_BLACK_DELETE_FAILED = 5052;
  ///用户黑名单，黑名称已存在
  static const int LVIM_PRIVATE_BLACK_EXSIT = 5053;
  ///用户黑名单，黑名单不存在
  static const int LVIM_PRIVATE_BLACK_NOT_EXSIT = 5054;
  ///用户黑名单，用户黑名单数量超出限制
  static const int LVIM_PRIVATE_BLACK_LIMIT_ERROR = 5055;
  ///用户黑名单，用户已经被拉黑（发送私信时返回）
  static const int LVIM_SEND_MESSAGE_RESULT_USERBLACK = 5056;

}

class LVIM_MESSAGE_LVDTYPE{
  //消息类型
  //最小无效消息类型
  static const int IM_MESSAGE_LVDTYPE_MIN = -1;
  //直播间消息
  static const int IM_MESSAGE_LVDTYPE_ROOM = 20;
  //群组消息
  static const int IM_MESSAGE_LVDTYPE_GROUP = 15;
  //群组消息
  static const int IM_MESSAGE_LVDTYPE_GROUP_T = 15;
  //私信消息
  static const int IM_MESSAGE_LVDTYPE_PRIVATE = 17;
  //推送消息
  static const int IM_MESSAGE_LVDTYPE_PUSH = 12;
  //事件消息
  static const int IM_MESSAGE_LVDTYPE_EVENT = 32;
  //公告消息
  static const int IM_MESSAGE_LVDTYPE_OFFICIAL = 31;
  //最大无效消息类型
  static const int IM_MESSAGE_LVDTYPE_MAX = 999;
}

//解析媒体json 类型
enum LVIMMediaJsonType{
  None,
  Audio,
  Image,
  Video
}

/// 即时通讯网络状态
class LVIMConnectState {
  ///域名解析失败
  static const int CONNECT_STATE_PARSE_FAILED = 1;

  ///域名解析成功
  static const int CONNECT_STATE_PARSE_SUCCESSED = 2;

  ///连接失败
  static const int CONNECT_STATE_CONNECT_FAILED = 3;

  ///连接超时
  static const int CONNECT_STATE_CONNECT_TIMEOUT = 4;

  ///连接成功
  static const int CONNECT_STATE_CONNECT_SUCCESSED = 5;

  ///数据正常发送
  static const int CONNECT_STATE_REQUEST_COMPLETED = 6;

  ///数据正常返回
  static const int CONNECT_STATE_RESPONSE_COMPLETED = 7;
}

/// 消息发送状态
class LVIMMessageSendState {
  ///消息发送中
  static const int SEND_STATE_SENDING = 0;
  ///消息发送失败
  static const int SEND_STATE_FAILED = 1;
  ///消息发送成功——对方未读
  static const int SEND_STATE_SENT_SUCC_UNREAD = 1;
  ///消息发送成功——对方已读
  static const int SEND_STATE_SENT_SUCC_READ = 3;
  ///消息已收到——自己未读
  static const int SEND_STATE_RECEIVED_UNREAD = 4;
  ///消息已收到——自己已读
  static const int SEND_STATE_RECEIVED_READ = 5;
  ///消息多媒体转码失败;暂时只有视频
  static const int SEND_STATE_ENCODE_MEDIA_FAILED = 6;
  ///消息上传多媒体文件失败
  static const int SEND_STATE_MEDIA_FAILED = 7;
  ///消息已读回执
  static const int SEND_STATE_READED_ACK = 8;
}

class LVUser {
  String userId;
  List<String> pullUrls; // 拉流url集合
}

class LinkvLoginRoomResult {
  int code;
  List<LVUser> users;
}

class LVVideoStatistic {
  // 音视频数据统计信息
  int videoSentPackets; // 视频总发送包数量
  int videoSentKBytes; // 视频总发送字节数
  int videoFps; // 视频输入帧率（视频帧率）
  int videoLostPackets; // 视频丢包总数
  int videoBitrateBps; // 视频码率
  int videoRtt; // 音频包 RTT，单位 ms
  int videoLostPercent; // 累计视频丢包百分比
  int frameWidth; // 推流：编码视频宽，拉流：输入视频帧宽
  int frameHeight; // 推流：编码视频高，拉流：输入视频帧高

  static LVVideoStatistic convertFromMap(dynamic args) {
    LVVideoStatistic v = LVVideoStatistic();
    v.videoSentPackets = args["videoSentPackets"];
    v.videoSentKBytes = args["videoSentKBytes"];
    v.videoFps = args["videoFps"];
    v.videoLostPackets = args["videoLostPackets"];
    v.videoBitrateBps = args["videoBitrateBps"];
    v.videoRtt = args["videoRtt"];
    v.videoLostPercent = args["videoLostPercent"];
    v.frameWidth = args["frameWidth"];
    v.frameHeight = args["frameHeight"];

    return v;
  }
}

/// 发送消息的结果
class SendMessageResult {
  int eCode;
  int rcode;
  var msg;

  static SendMessageResult convertFromMap(dynamic args) {
    SendMessageResult sendMessageResult = SendMessageResult();
    var newMsg = null;
    if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_IMAGE){
      newMsg = LVIMImageMsg();
    }else if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_AUDIO){
        newMsg = LVIMAudioMsg();
    }else if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_VIDEO){
      newMsg = LVIMVideoMsg();
    }else{
      newMsg = LVIMMsg();
    }
    newMsg.convertFromMap(args);
    sendMessageResult.msg = newMsg;
    sendMessageResult.eCode = args["eCode"];
    if (args["rcode"] != null){
      sendMessageResult.rcode = args["rcode"];
    }
    return sendMessageResult;
  }

}

/// 上传push token的返回结果
/// eCode 错误码，0为成功，非0为失败。
/// msg  错误信息
class UploadPushTokenResult {
  int eCode;
  String msg;

  static UploadPushTokenResult convertFromMap(dynamic args) {
    UploadPushTokenResult result = UploadPushTokenResult();
    result.eCode = args["eCode"];
    result.msg = args["msg"];
    return result;
  }
}

/// 用户私信黑名单列表的结果
class PrivateMessageBlackResult {
  int eCode;
  List<String> response;

  static PrivateMessageBlackResult convertFromMap(dynamic args) {
    PrivateMessageBlackResult privateMessageBlackResult = PrivateMessageBlackResult();
    privateMessageBlackResult.eCode = args["eCode"];
    privateMessageBlackResult.response = args["response"];
    return privateMessageBlackResult;
  }
}

/// 推送内容
/// title 推送标题
/// body  推送内容
/// extra 推送自定义负载数据
class LVPushContent {
  String title;
  String body;
  String extra;
  String click_action;
}

/// 会话
class LVIMSession {
  LVIMMsg lastMsg;
  int unreadCount;
}

==> linkv_rtc_im_mini-0.0.4.tar.gz: lib/linkv_api_defines.dart <==
import 'dart:typed_data';
import 'dart:convert' show utf8;

import 'package:linkv_rtc_im_mini/bean/lv_im_audio_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_image_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_msg.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_video_msg.dart';

enum LVCameraPosition {
  back, // 后置摄像头
  front, // 前置摄像头
}

enum LVAVConfig {
  PROFILE_180P,
  PROFILE_270P,
  PROFILE_360P,
  PROFILE_540P,
  PROFILE_720P,
}

enum LVBeauty {
  Beauty, // 美颜级别
  Bright, // 明亮度
  Tone // 饱和度
}

class LVIMEnumDefine {

  ///操作的数据库类型
  ///房间数据库类型
  static const int LVIMDB_TYPE_ROOM = 1;
  ///群组数据库类型
  static const int LVIMDB_TYPE_GROUP = 2;
  ///私信数据库类型
  static const int LVIMDB_TYPE_PRIVATE = 3;
  ///系统数据库类型
  static const int LVIMDB_TYPE_SYSTEM = 4;

  /// 直播间数据管理
  /// 直播间数据添加
  static const int LVIM_ROOM_DATA_ADD          = 0;
  static const int LVIM_ROOM_DATA_UPDATE      = 1; ///直播间数据修改
  static const int LVIM_ROOM_DATA_REMOVE      = 2; ///直播间数据删除
  static const int LVIM_ROOM_DATA_QUERY       = 3; ///查询直播间某一个数据
  static const int LVIM_ROOM_DATA_QUERY_ALL   = 4; ///查询直播间所有数据

  static const int LVIM_ROOM_USER_DATA_ADD    = 0; ///直播间用户数据添加
  static const int LVIM_ROOM_USER_DATA_UPDATE = 1; ///直播间用户数据修改
  static const int LVIM_ROOM_USER_DATA_REMOVE = 2; ///直播间用户数据删除
  static const int LVIM_ROOM_USER_DATA_QUERY  = 4; ///查询直播间用户某一个数据
  static const int LVIM_ROOM_USER_DATA_QUERY_ALL  = 5; ///查询直播间用户所有数据

  ///登录类型
  ///手动登录
  static const int LVIM_LOGIN_TYPE_MANUAL = 0;
  ///自动登录
  static const int LVIM_LOGIN_TYPE_AUTO = 1;

  ///登录被踢类型
  ///有新的设备登录账号
  static const int LVIM_LOGIN_KICKED_CODE_KICKED = -5;
  ///用户拉黑
  static const int LVIM_LOGIN_KICKED_CODE_BAN = -9;

  /// 消息类型
  ///文本类协议
  static const int IM_SUBTYPE_TEXT = 0;

  ///图片类协议
  static const int IM_SUBTYPE_IMAGE = 1;

  ///音频类协议
  static const int IM_SUBTYPE_AUDIO = 2;

  ///视频类协议
  static const int IM_SUBTYPE_VIDEO = 3;

  ///军团文本类协议
  static const int IM_SUBTYPE_LEGION_TEXT = 5;

  ///军团图片类协议
  static const int IM_SUBTYPE_LEGION_IMAGE = 6;

  ///军团音频类协议
  static const int IM_SUBTYPE_LEGION_AUDIO = 7;

  ///军团视频类协议
  static const int IM_SUBTYPE_LEGION_VIDEO = 8;

  ///直播间消息
  static const int IM_SUBTYPE_ROOMDIY = 80;

  ///无效最小值
  static const int IM_MEDIA_FILE_TYPE_MIN = 0;
  ///图片文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_IMAGE = 1;
  ///语音文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_AUDIO = 2;
  ///视频文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_VIDEO = 3;
  ///文件文件(私信)
  static const int IM_MEDIA_FILE_PRIVATE_FILE = 4;
  ///图片文件(群组)
  static const int IM_MEDIA_FILE_GROUP_IMAGE = 5;
  ///语音文件(群组)
  static const int IM_MEDIA_FILE_GROUP_AUDIO = 6;
  ///视频文件(群组)
  static const int IM_MEDIA_FILE_GROUP_VIDEO = 7;
  ///文件文件(群组)
  static const int IM_MEDIA_FILE_GROUP_FILE = 8;
  ///无效最大值
  static const int IM_MEDIA_FILE_TYPE_MAX = 9;

  ///用户黑名单 参数错误，请确认 toUserId 是否为空，超出长度
  static const int LVIM_PRIVATE_BLACK_PARAMS_FAILED = 5050;
  ///用户黑名单，黑名单创建失败
  static const int LVIM_PRIVATE_BLACK_CREATE_FAILED = 5051;
  ///用户黑名单，黑名单删除失败
  static const int LVIM_PRIVATE_BLACK_DELETE_FAILED = 5052;
  ///用户黑名单，黑名称已存在
  static const int LVIM_PRIVATE_BLACK_EXSIT = 5053;
  ///用户黑名单，黑名单不存在
  static const int LVIM_PRIVATE_BLACK_NOT_EXSIT = 5054;
  ///用户黑名单，用户黑名单数量超出限制
  static const int LVIM_PRIVATE_BLACK_LIMIT_ERROR = 5055;
  ///用户黑名单，用户已经被拉黑（发送私信时返回）
  static const int LVIM_SEND_MESSAGE_RESULT_USERBLACK = 5056;

}

class LVIM_MESSAGE_LVDTYPE{
  //消息类型
  //最小无效消息类型
  static const int IM_MESSAGE_LVDTYPE_MIN = -1;
  //直播间消息
  static const int IM_MESSAGE_LVDTYPE_ROOM = 20;
  //群组消息
  static const int IM_MESSAGE_LVDTYPE_GROUP = 15;
  //群组消息
  static const int IM_MESSAGE_LVDTYPE_GROUP_T = 15;
  //私信消息
  static const int IM_MESSAGE_LVDTYPE_PRIVATE = 17;
  //推送消息
  static const int IM_MESSAGE_LVDTYPE_PUSH = 12;
  //事件消息
  static const int IM_MESSAGE_LVDTYPE_EVENT = 32;
  //公告消息
  static const int IM_MESSAGE_LVDTYPE_OFFICIAL = 31;
  //最大无效消息类型
  static const int IM_MESSAGE_LVDTYPE_MAX = 999;
}

//解析媒体json 类型
enum LVIMMediaJsonType{
  None,
  Audio,
  Image,
  Video
}

/// 即时通讯网络状态
class LVIMConnectState {
  ///域名解析失败
  static const int CONNECT_STATE_PARSE_FAILED = 1;

  ///域名解析成功
  static const int CONNECT_STATE_PARSE_SUCCESSED = 2;

  ///连接失败
  static const int CONNECT_STATE_CONNECT_FAILED = 3;

  ///连接超时
  static const int CONNECT_STATE_CONNECT_TIMEOUT = 4;

  ///连接成功
  static const int CONNECT_STATE_CONNECT_SUCCESSED = 5;

  ///数据正常发送
  static const int CONNECT_STATE_REQUEST_COMPLETED = 6;

  ///数据正常返回
  static const int CONNECT_STATE_RESPONSE_COMPLETED = 7;
}

/// 消息发送状态
class LVIMMessageSendState {
  ///消息发送中
  static const int SEND_STATE_SENDING = 0;
  ///消息发送失败
  static const int SEND_STATE_FAILED = 1;
  ///消息发送成功——对方未读
  static const int SEND_STATE_SENT_SUCC_UNREAD = 2;
  ///消息发送成功——对方已读
  static const int SEND_STATE_SENT_SUCC_READ = 3;
  ///消息已收到——自己未读
  static const int SEND_STATE_RECEIVED_UNREAD = 4;
  ///消息已收到——自己已读
  static const int SEND_STATE_RECEIVED_READ = 5;
  ///消息多媒体转码失败;暂时只有视频
  static const int SEND_STATE_ENCODE_MEDIA_FAILED = 6;
  ///消息上传多媒体文件失败
  static const int SEND_STATE_MEDIA_FAILED = 7;
  ///消息已读回执
  static const int SEND_STATE_READED_ACK = 8;
}

class LVUser {
  String userId = "";
  List<String> pullUrls = []; // 拉流url集合
}

class LinkvLoginRoomResult {
  int code = -1;
  List<LVUser> users = [];
}

class LVVideoStatistic {
  // 音视频数据统计信息
  int videoSentPackets = 0; // 视频总发送包数量
  int videoSentKBytes = 0; // 视频总发送字节数
  int videoFps = 0; // 视频输入帧率（视频帧率）
  int videoLostPackets = 0; // 视频丢包总数
  int videoBitrateBps = 0; // 视频码率
  int videoRtt = 0; // 音频包 RTT，单位 ms
  int videoLostPercent = 0; // 累计视频丢包百分比
  int frameWidth = 0; // 推流：编码视频宽，拉流：输入视频帧宽
  int frameHeight = 0; // 推流：编码视频高，拉流：输入视频帧高

  static LVVideoStatistic convertFromMap(dynamic args) {
    LVVideoStatistic v = LVVideoStatistic();
    v.videoSentPackets = args["videoSentPackets"];
    v.videoSentKBytes = args["videoSentKBytes"];
    v.videoFps = args["videoFps"];
    v.videoLostPackets = args["videoLostPackets"];
    v.videoBitrateBps = args["videoBitrateBps"];
    v.videoRtt = args["videoRtt"];
    v.videoLostPercent = args["videoLostPercent"];
    v.frameWidth = args["frameWidth"];
    v.frameHeight = args["frameHeight"];

    return v;
  }
}

/// 发送消息的结果
class SendMessageResult {
  int eCode = -1;
  int rcode = -1;
  var msg;

  static SendMessageResult convertFromMap(dynamic args) {
    SendMessageResult sendMessageResult = SendMessageResult();
    var newMsg = null;
    if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_IMAGE){
      newMsg = LVIMImageMsg();
    }else if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_AUDIO){
        newMsg = LVIMAudioMsg();
    }else if (args["subType"] != null && args["subType"].toInt() == LVIMEnumDefine.IM_SUBTYPE_VIDEO){
      newMsg = LVIMVideoMsg();
    }else{
      newMsg = LVIMMsg();
    }
    newMsg.convertFromMap(args);
    sendMessageResult.msg = newMsg;
    sendMessageResult.eCode = args["eCode"] ?? -1;
    if (args["rcode"] != null){
      sendMessageResult.rcode = args["rcode"];
    }
    return sendMessageResult;
  }

}

/// 上传push token的返回结果
/// eCode 错误码，0为成功，非0为失败。
/// msg  错误信息
class UploadPushTokenResult {
  int eCode = -1;
  String msg = "";

  static UploadPushTokenResult convertFromMap(dynamic args) {
    UploadPushTokenResult result = UploadPushTokenResult();
    result.eCode = args["eCode"] ?? -1;
    result.msg = args["msg"] ?? "";
    return result;
  }
}

/// 用户私信黑名单列表的结果
class PrivateMessageBlackResult {
  int eCode = -1;
  List<String> response = [];

  static PrivateMessageBlackResult convertFromMap(dynamic args) {
    PrivateMessageBlackResult privateMessageBlackResult = PrivateMessageBlackResult();
    privateMessageBlackResult.eCode = args["eCode"] ?? -1;
    privateMessageBlackResult.response = args["response"] ?? [];
    return privateMessageBlackResult;
  }
}

/// 推送内容
/// title 推送标题
/// body  推送内容
/// extra 推送自定义负载数据
class LVPushContent {
  String title = "";
  String body = "";
  String extra = "";
  String click_action = "";
}

/// 会话
class LVIMSession {
  LVIMMsg? lastMsg;
  int unreadCount = -1;
}

/// 根据时间戳标记消息已读的返回结果
class SendReadedAckWithStimeResult {

  /// 客户端状态码，0为成功，非0为失败。
  int eCode = -1;

  /// 服务器状态码，0为成功，非0为失败。
  int rcode = -1;

  static SendReadedAckWithStimeResult convertFromMap(dynamic args) {
    SendReadedAckWithStimeResult sendReadedAckWithStimeResult = SendReadedAckWithStimeResult();
    sendReadedAckWithStimeResult.eCode = args["eCode"] ?? -1;
    sendReadedAckWithStimeResult.rcode = args["rCode"] ?? -1;
    return sendReadedAckWithStimeResult;
  }

}
